#
# spec file for package perl-autovivification
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-autovivification
Version:        0.18
Release:        1.41
%define cpan_name autovivification
Summary:        Lexically disable autovivification
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/autovivification/
Source0:        https://cpan.metacpan.org/authors/id/V/VP/VPIT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
When an undefined variable is dereferenced, it gets silently upgraded to an
array or hash reference (depending of the type of the dereferencing). This
behaviour is called _autovivification_ and usually does what you mean (e.g.
when you store a value) but it may be unnatural or surprising because your
variables gets populated behind your back. This is especially true when
several levels of dereferencing are involved, in which case all levels are
vivified up to the last, or when it happens in intuitively read-only
constructs like 'exists'.

This pragma lets you disable autovivification for some constructs and
optionally throws a warning or an error when it would have happened.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README samples

%changelog
* Sun Nov  5 2017 coolo@suse.com
- updated to 0.18
  see /usr/share/doc/packages/perl-autovivification/Changes
  0.18    2017-11-04 15:30 UTC
    + Fix : [RT #123411] : Compatibility with CV-in-stash optimisation
    Thanks Father Chrysostomos for reporting and contributing a
    patch.
    + Fix : [RT #122956] : strict/warn flags seem to simply do nothing
    The documentation has been amended to clarify how these two
    options are supposed to be used.
    Thanks Christian Walde for reporting.
* Thu Aug  3 2017 coolo@suse.com
- updated to 0.17
  see /usr/share/doc/packages/perl-autovivification/Changes
  0.17    2017-07-31 17:15 UTC
    + Chg : A large chunk of boilerplate XS code, which is also used in
    other XS modules, has been factored out of the main .xs file
    to a collection of .h files in the xsh subdirectory.
    + Fix : The new optimization in perl 5.27.3 for scalar(keys(%%$hashref))
    is now correcty supported.
* Thu Jul  2 2015 coolo@suse.com
- updated to 0.16
  see /usr/share/doc/packages/perl-autovivification/Changes
  0.16    2015-07-01 14:30 UTC
    + Fix : Broken linkage on Windows.
* Fri May 15 2015 coolo@suse.com
- updated to 0.15
  see /usr/share/doc/packages/perl-autovivification/Changes
  0.15    2015-05-14 20:35 UTC
    + Chg : The new environment variable to enable thread tests on older
    perls is PERL_FORCE_TEST_THREADS. Note that this variable
    should only be turned on by authors.
    + Fix : The module has been taught about the new multideref
    optimization, and will function properly on perl 5.21.11 and
    above.
    + Fix : The module will no longer crash or behave erratically when it
    is loaded by several threads (or Windows emulated processes)
    ran in parallel.
    + Fix : Update the Windows ActivePerl + gcc 3.4 workaround for
    ExtUtils::MakeMaker 7.04. Thanks Christian Walde for reporting
    and feedback on this issue.
    + Fix : Be really compatible with the optional OP_PARENT feature.
    + Tst : $ENV{$Config{ldlibpthname}} is now preserved on all platforms,
    which will address failures of t/43-peep.t and
    t/51-threads-teardown.t with unusual compilers (like icc) that
    link all their compiled objects to their own libraries.
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.14
  see /usr/share/doc/packages/perl-autovivification/Changes
  0.14    2014-11-01 22:25 UTC
    + Fix : [RT #99458] : AnyEvent::Loop hangs if autovivification 0.13 is
    loaded
    [RT #99904] : 'no autovivification' breaks Lingua::EN::Inflect
    from a distance
    This was a regression in 0.13 which caused the peephole
    optimizer to loop infinitely on "... while 1" constructs.
    However, the Lingua::EN::Inflect problem only occured in perl
    5.20 and above.
    Thanks Toshio Ito and Kent Fredric for reporting.
  0.13    2014-10-04 16:55 UTC
    This release contains a change that, while being very likely to be safe,
    can potentially cause freezes during code compilation. Every release
    should be carefully tested before being put in production, but this is
    especially true for this one.
    + Add : Support for the PERL_OP_PARENT optional feature introduced in
    perl 5.21.2.
    + Doc : The CAVEATS section now warns about the global slowdown during
    compilation caused by this pragma.
    + Fix : [RT #97703] : Android support
    t/51-threads-teardown.t will no longer fail on Android.
    Thanks Brian Fraser for reporting.
    + Fix : Segfaults in eval in an END block of a Win32 pseudo-fork.
    + Fix : Segfaults during global destruction of a thread or a
    pseudo-fork.
    + Opt : The global slowdown caused by this module has been greatly
    reduced.
    Thanks Ævar Arnfjörð Bjarmason for reporting and testing the
    change.
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.12
    + Fix : Check functions are now replaced and restored in a thread-safe
    manner, either by using the wrap_op_checker() function from perl
    when it is available (starting from perl 5.16) or by taking the
    OP_REFCNT mutex on older perls.
    + Tst : Author tests are no longer bundled with this distribution.
    They are only made available to authors in the git repository.
* Mon Sep  2 2013 werner@suse.de
- Update to version 0.11
  + Doc : POD tweaks and clarifications.
  + Tst : Threads tests will not fail anymore if resources constraints
    prevent the system from creating all the required threads.
  + Tst : Author tests overhaul.
  + Fix : The pragma no longer vivifies the "autovivification" entry
    in the hints hash %%^H on perl 5.8.
* Thu Apr 14 2011 coolo@opensuse.org
- initial package 0.09
  * created by cpanspec 1.78.04
